==> yy-formulas-1.0.1.tgz: package/es/components/FixedComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import ReferComponents from './ReferComponents';

var FixedComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FixedComponents, _React$Component);

  function FixedComponents(props) {
    var _this;

    _classCallCheck(this, FixedComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FixedComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      record: {},
      record2: {},
      recordValue: {}
    };
    return _this;
  }

  _createClass(FixedComponents, [{
    key: "onChange",
    value: function onChange(type, value) {
      var _this2 = this;

      console.log([type, value]);
      this.setState(_defineProperty({}, type, value), function () {
        if (type === 'record') {
          _this2.setState({
            record2: {},
            recordValue: {}
          });
        }

        if (type === 'record2') {
          _this2.setState({
            recordValue: {}
          });
        }

        if (type === 'recordValue' && value.id) {
          _this2.props.onInsertValue(' getID("' + _this2.state.record.code + '","' + value.text + '","' + value.id + '") ');

          _this2.props.onDesc('getID');
        }
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData;
      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-horizontal"
      }, React.createElement("div", {
        className: "form-group"
      }, React.createElement("label", {
        className: "col-sm-2 control-label"
      }, "\u6863\u6848"), React.createElement("div", {
        className: "col-sm-10"
      }, React.createElement(ReferComponents, {
        url: ReferDataUrl,
        fixedData: fixedData,
        value: this.state.record,
        onChange: this.onChange.bind(this, 'record')
      }))), React.createElement("div", {
        className: "form-group"
      }, React.createElement("label", {
        className: "col-sm-2 control-label"
      }, "\u6863\u6848\u503C"), React.createElement("div", {
        className: "col-sm-10"
      }, this.state.record.code === 'accsubject' ? React.createElement(React.Fragment, null, React.createElement(ReferComponents, {
        url: ReferDataUrl,
        isCode: true,
        fixedData: _extends({}, fixedData, {
          refCode: 'accsubjectchart',
          refType: 'table',
          fields: ['id', 'code', 'name'],
          orderby: 'code asc',
          displayFields: ['id', 'code', 'name']
        }),
        disabled: !this.state.record.code,
        value: this.state.record2,
        onChange: this.onChange.bind(this, 'record2')
      }), React.createElement(ReferComponents, {
        url: ReferDataUrl,
        isCode: true,
        fixedData: _extends({}, fixedData, {
          refCode: this.state.record.code,
          filterCondition: '{"accsubjectchart":"' + this.state.record2.id + '"}',
          refType: 'table',
          fields: ['id', 'code', 'name'],
          orderby: 'code asc',
          displayFields: ['id', 'code', 'name']
        }),
        disabled: !this.state.record2.code,
        value: this.state.recordValue,
        onChange: this.onChange.bind(this, 'recordValue')
      })) : React.createElement(ReferComponents, {
        url: ReferDataUrl,
        fixedData: _extends({}, fixedData, {
          refCode: this.state.record.code
        }),
        disabled: !this.state.record.code,
        value: this.state.recordValue,
        onChange: this.onChange.bind(this, 'recordValue')
      })))));
    }
  }]);

  return FixedComponents;
}(React.Component);

FixedComponents.propTypes = {
  item: PropTypes.object,
  ReferDataUrl: PropTypes.string,
  fixedData: PropTypes.object
};
FixedComponents.defaultProps = {
  item: {},
  ReferDataUrl: '',
  fixedData: {}
};
polyfill(FixedComponents);
export default FixedComponents;

==> yy-formulas-1.0.7.tgz: package/es/components/FixedComponents.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import ReferComponents from './ReferComponents';

var FixedComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(FixedComponents, _React$Component);

  function FixedComponents(props) {
    var _this;

    _classCallCheck(this, FixedComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FixedComponents).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.state = {
      record: {},
      record2: {},
      recordValue: {}
    };
    return _this;
  }

  _createClass(FixedComponents, [{
    key: "onChange",
    value: function onChange(type, value) {
      var _this2 = this;

      // console.log([type,value])
      this.setState(_defineProperty({}, type, value), function () {
        if (type === 'record') {
          _this2.setState({
            record2: {},
            recordValue: {}
          });
        }

        if (type === 'record2') {
          _this2.setState({
            recordValue: {}
          });
        }

        if (type === 'recordValue' && value.id) {
          _this2.props.onInsertValue(' getID("' + _this2.state.record.code + '","' + value.title + '","' + value.id + '") ');

          _this2.props.onDesc('getID');
        }
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData;
      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-horizontal"
      }, React.createElement("div", {
        className: "form-group"
      }, React.createElement("label", {
        className: "col-sm-2 control-label"
      }, this.props.item.showName1), React.createElement("div", {
        className: "col-sm-10"
      }, React.createElement(ReferComponents, {
        url: ReferDataUrl,
        fixedData: fixedData,
        value: this.state.record,
        placeholder: this.props.item.placeholder,
        notFoundContent: this.props.item.notFoundContent,
        onChange: this.onChange.bind(this, 'record')
      }))), React.createElement("div", {
        className: "form-group"
      }, React.createElement("label", {
        className: "col-sm-2 control-label"
      }, this.props.item.showName2), React.createElement("div", {
        className: "col-sm-10"
      }, this.state.record.code === 'accsubject' ? React.createElement("div", null, React.createElement(ReferComponents, {
        url: ReferDataUrl,
        isCode: true,
        fixedData: _extends({}, fixedData, {
          refCode: 'accsubjectchart',
          refType: 'table',
          fields: ['id', 'code', 'name'],
          orderby: 'code asc',
          displayFields: ['id', 'code', 'name']
        }),
        disabled: !this.state.record.code,
        value: this.state.record2,
        placeholder: this.props.item.placeholder,
        notFoundContent: this.props.item.notFoundContent,
        onChange: this.onChange.bind(this, 'record2')
      }), React.createElement(ReferComponents, {
        url: ReferDataUrl,
        isCode: true,
        fixedData: _extends({}, fixedData, {
          refCode: this.state.record.code,
          filterCondition: '{"accsubjectchart":"' + this.state.record2.id + '"}',
          refType: 'table',
          fields: ['id', 'code', 'name'],
          orderby: 'code asc',
          displayFields: ['id', 'code', 'name']
        }),
        disabled: !this.state.record2.code,
        value: this.state.recordValue,
        placeholder: this.props.item.placeholder,
        notFoundContent: this.props.item.notFoundContent,
        onChange: this.onChange.bind(this, 'recordValue')
      })) : React.createElement(ReferComponents, {
        url: ReferDataUrl,
        fixedData: _extends({}, fixedData, {
          refCode: this.state.record.code
        }),
        disabled: !this.state.record.code,
        value: this.state.recordValue,
        placeholder: this.props.item.placeholder,
        notFoundContent: this.props.item.notFoundContent,
        onChange: this.onChange.bind(this, 'recordValue')
      })))));
    }
  }]);

  return FixedComponents;
}(React.Component);

FixedComponents.propTypes = {
  item: PropTypes.object,
  ReferDataUrl: PropTypes.string,
  fixedData: PropTypes.object
};
FixedComponents.defaultProps = {
  item: {},
  ReferDataUrl: '',
  fixedData: {}
};
polyfill(FixedComponents);
export default FixedComponents;
